jaclearn.datasets.image\_classification.cifar
=============================================

.. automodule:: jaclearn.datasets.image_classification.cifar

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      load_cifar
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: load_cifar


